# swspy

A package for performing shear wave splitting in an automated manner. Based on the eigenvalue method of Silver and Chan (1991), with multi-windowing of Teanby et al (2004), coordinate system transformations from Walsh et al (2013), automation methods based on Wustefeld et al (2010), and some other additions.

## To cite:

To be completed...


Zenodo citation:
TBC...

## Documentation:

Will be published on readthedocs.org in due course, once the package becomes open source.

In the meantime, to view the documentation, do:

open docs/build/html/index.html 

(or similar)

## Examples:

Various example notebooks can be found in the examples directory.